# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import base_pb2 as base__pb2


class grpcServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetupStream = channel.stream_stream(
                '/openiap.grpcService/SetupStream',
                request_serializer=base__pb2.envelope.SerializeToString,
                response_deserializer=base__pb2.envelope.FromString,
                )
        self.Signin = channel.unary_unary(
                '/openiap.grpcService/Signin',
                request_serializer=base__pb2.signin.SerializeToString,
                response_deserializer=base__pb2.signinreply.FromString,
                )


class grpcServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetupStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Signin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_grpcServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetupStream': grpc.stream_stream_rpc_method_handler(
                    servicer.SetupStream,
                    request_deserializer=base__pb2.envelope.FromString,
                    response_serializer=base__pb2.envelope.SerializeToString,
            ),
            'Signin': grpc.unary_unary_rpc_method_handler(
                    servicer.Signin,
                    request_deserializer=base__pb2.signin.FromString,
                    response_serializer=base__pb2.signinreply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'openiap.grpcService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class grpcService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetupStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/openiap.grpcService/SetupStream',
            base__pb2.envelope.SerializeToString,
            base__pb2.envelope.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Signin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/openiap.grpcService/Signin',
            base__pb2.signin.SerializeToString,
            base__pb2.signinreply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
